var chai = require('chai');
var chaiHttp = require('chai-http');
var assert = chai.assert;
var expect = chai.expect;
var should = chai.should(); //actually call the function
var server = require('../libs/app');

chai.use(chaiHttp);

describe('request enrollments', function(){

  it('should list enrollments', function(done){
    chai.request(server)
      .get('/api/v1/enrollments')
      .end(function(err, res){
        res.should.have.status(200);
        res.should.be.json;
        res.body.should.have.property('result');
        res.body.result.should.be.a('array');
        res.body.result[0].should.have.property('name');
        res.body.result[0].should.have.property('total');
        done();
      })
  });
});

describe('request regions', function(){

  it('should list all regions', function(done){
    chai.request(server)
      .get('/api/v1/regions')
      .end(function(err, res){
        res.should.have.status(200);
        res.should.be.json;
        res.body.should.have.property('result');
        res.body.result.should.be.a('array');
        res.body.result[0].should.have.property('pk_regiao_id');
        res.body.result[0].should.have.property('nome');
        done();
      })
  });

  it('should list region by id', function(done){
    chai.request(server)
      .get('/api/v1/regions/1')
      .end(function(err, res){
        res.should.have.status(200);
        res.should.be.json;
        res.body.should.have.property('result');
        res.body.result.should.be.a('array');
        res.body.result.should.have.length(1);
        res.body.result[0].should.have.property('pk_regiao_id');
        res.body.result[0].should.have.property('nome');
        done();
      })
  });
});

describe('request states', function(){

  it('should list all states', function(done){
    chai.request(server)
      .get('/api/v1/states')
      .end(function(err, res){
        res.should.have.status(200);
        res.should.be.json;
        res.body.should.have.property('result');
        res.body.result.should.be.a('array');
        res.body.result[0].should.have.property('pk_estado_id');
        res.body.result[0].should.have.property('fk_regiao_id');
        res.body.result[0].should.have.property('nome');
        done();
      })
  });

  it('should list a state by id', function(done){
    chai.request(server)
      .get('/api/v1/states/11')
      .end(function(err, res){
        res.should.have.status(200);
        res.should.be.json;
        res.body.should.have.property('result');
        res.body.result.should.be.a('array');
        res.body.result.should.have.length(1);
        res.body.result[0].should.have.property('pk_estado_id');
        res.body.result[0].should.have.property('fk_regiao_id');
        res.body.result[0].should.have.property('nome');
        done();
      })
  });

  it('should list states by region id', function(done){
    chai.request(server)
      .get('/api/v1/states/region/1')
      .end(function(err, res){
        res.should.have.status(200);
        res.should.be.json;
        res.body.should.have.property('result');
        res.body.result.should.be.a('array');
        res.body.result[0].should.have.property('pk_estado_id');
        res.body.result[0].should.have.property('fk_regiao_id');
        res.body.result[0].should.have.property('nome');
        done();
      })
  });
});

describe('request cities', function(){

  it('should list all cities', function(done){
    chai.request(server)
      .get('/api/v1/cities')
      .end(function(err, res){
        res.should.have.status(200);
        res.should.be.json;
        res.body.should.have.property('result');
        res.body.result.should.be.a('array');
        res.body.result[0].should.have.property('pk_municipio_id');
        res.body.result[0].should.have.property('fk_estado_id');
        res.body.result[0].should.have.property('nome');
        res.body.result[0].should.have.property('codigo_ibge');
        done();
      })
  });

  it('should list a city by id', function(done){
    chai.request(server)
      .get('/api/v1/cities/1')
      .end(function(err, res){
        res.should.have.status(200);
        res.should.be.json;
        res.body.should.have.property('result');
        res.body.result.should.be.a('array');
        res.body.result[0].should.have.property('pk_municipio_id');
        res.body.result[0].should.have.property('fk_estado_id');
        res.body.result[0].should.have.property('nome');
        res.body.result[0].should.have.property('codigo_ibge');
        done();
      })
  });

  it('should list a city by codigo_ibge', function(done){
    chai.request(server)
      .get('/api/v1/cities/ibge/1200013')
      .end(function(err, res){
        res.should.have.status(200);
        res.should.be.json;
        res.body.should.have.property('result');
        res.body.result.should.be.a('array');
        res.body.result[0].should.have.property('pk_municipio_id');
        res.body.result[0].should.have.property('fk_estado_id');
        res.body.result[0].should.have.property('nome');
        res.body.result[0].should.have.property('codigo_ibge');
        done();
      })
  });

});
